<?php

namespace Nico\Nico\Http\Controllers;

use App\Http\Controllers\AdminController as BaseController;
use Form;
use Nico\Nico\Http\Requests\CommuneRequest;
use Nico\Nico\Interfaces\CommuneRepositoryInterface;
use Nico\Nico\Models\Commune;

/**
 * Admin web controller class.
 */
class CommuneAdminController extends BaseController
{
    // use CommuneWorkflow;
    /**
     * Initialize commune controller.
     *
     * @param type CommuneRepositoryInterface $commune
     *
     * @return type
     */
    public function __construct(CommuneRepositoryInterface $commune)
    {
        $this->repository = $commune;
        parent::__construct();
    }

    /**
     * Display a list of commune.
     *
     * @return Response
     */
    public function index(CommuneRequest $request)
    {
        if ($request->wantsJson()) {
            return $this->getJson($request);
        }
        $this   ->theme->prependTitle(trans('nico::commune.names').' :: ');
        return $this->theme->of('nico::admin.commune.index')->render();
    }

    /**
     * Display a list of commune.
     *
     * @return Response
     */
    public function getJson(CommuneRequest $request)
    {
        $pageLimit = $request->input('pageLimit');

        $communes  = $this->repository
                ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
                ->setPresenter('\\Nico\\Nico\\Repositories\\Presenter\\CommuneListPresenter')
                ->scopeQuery(function($query){
                    return $query->orderBy('id','DESC');
                })->paginate($pageLimit);
        $communes['recordsTotal']    = $communes['meta']['pagination']['total'];
        $communes['recordsFiltered'] = $communes['meta']['pagination']['total'];
        $communes['request']         = $request->all();
        return response()->json($communes, 200);

    }

    /**
     * Display commune.
     *
     * @param Request $request
     * @param Model   $commune
     *
     * @return Response
     */
    public function show(CommuneRequest $request, Commune $commune)
    {
        if (!$commune->exists) {
            return response()->view('nico::admin.commune.new', compact('commune'));
        }

        Form::populate($commune);
        return response()->view('nico::admin.commune.show', compact('commune'));
    }

    /**
     * Show the form for creating a new commune.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(CommuneRequest $request)
    {

        $commune = $this->repository->newInstance([]);

        Form::populate($commune);

        return response()->view('nico::admin.commune.create', compact('commune'));

    }

    /**
     * Create new commune.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(CommuneRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.web');
            $commune          = $this->repository->create($attributes);

            return response()->json([
                'message'  => trans('messages.success.updated', ['Module' => trans('nico::commune.name')]),
                'code'     => 204,
                'redirect' => trans_url('/admin/nico/commune/'.$commune->getRouteKey())
            ], 201);


        } catch (Exception $e) {
            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
            ], 400);
        }
    }

    /**
     * Show commune for editing.
     *
     * @param Request $request
     * @param Model   $commune
     *
     * @return Response
     */
    public function edit(CommuneRequest $request, Commune $commune)
    {
        Form::populate($commune);
        return  response()->view('nico::admin.commune.edit', compact('commune'));
    }

    /**
     * Update the commune.
     *
     * @param Request $request
     * @param Model   $commune
     *
     * @return Response
     */
    public function update(CommuneRequest $request, Commune $commune)
    {
        try {

            $attributes = $request->all();

            $commune->update($attributes);

            return response()->json([
                'message'  => trans('messages.success.updated', ['Module' => trans('nico::commune.name')]),
                'code'     => 204,
                'redirect' => trans_url('/admin/nico/commune/'.$commune->getRouteKey())
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/nico/commune/'.$commune->getRouteKey()),
            ], 400);

        }
    }

    /**
     * Remove the commune.
     *
     * @param Model   $commune
     *
     * @return Response
     */
    public function destroy(CommuneRequest $request, Commune $commune)
    {

        try {

            $t = $commune->delete();

            return response()->json([
                'message'  => trans('messages.success.deleted', ['Module' => trans('nico::commune.name')]),
                'code'     => 202,
                'redirect' => trans_url('/admin/nico/commune/0'),
            ], 202);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/nico/commune/'.$commune->getRouteKey()),
            ], 400);
        }
    }

}
