<?php

namespace Nico\Nico\Http\Controllers;

use App\Http\Controllers\AdminController as BaseController;
use Form;
use Nico\Nico\Http\Requests\DisciplineRequest;
use Nico\Nico\Interfaces\DisciplineRepositoryInterface;
use Nico\Nico\Models\Discipline;

/**
 * Admin web controller class.
 */
class DisciplineAdminController extends BaseController
{
    // use DisciplineWorkflow;
    /**
     * Initialize discipline controller.
     *
     * @param type DisciplineRepositoryInterface $discipline
     *
     * @return type
     */
    public function __construct(DisciplineRepositoryInterface $discipline)
    {
        $this->repository = $discipline;
        parent::__construct();
    }

    /**
     * Display a list of discipline.
     *
     * @return Response
     */
    public function index(DisciplineRequest $request)
    {
        if ($request->wantsJson()) {
            return $this->getJson($request);
        }
        $this   ->theme->prependTitle(trans('nico::discipline.names').' :: ');
        return $this->theme->of('nico::admin.discipline.index')->render();
    }

    /**
     * Display a list of discipline.
     *
     * @return Response
     */
    public function getJson(DisciplineRequest $request)
    {
        $pageLimit = $request->input('pageLimit');

        $disciplines  = $this->repository
                ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
                ->setPresenter('\\Nico\\Nico\\Repositories\\Presenter\\DisciplineListPresenter')
                ->scopeQuery(function($query){
                    return $query->orderBy('id','DESC');
                })->paginate($pageLimit);
        $disciplines['recordsTotal']    = $disciplines['meta']['pagination']['total'];
        $disciplines['recordsFiltered'] = $disciplines['meta']['pagination']['total'];
        $disciplines['request']         = $request->all();
        return response()->json($disciplines, 200);

    }

    /**
     * Display discipline.
     *
     * @param Request $request
     * @param Model   $discipline
     *
     * @return Response
     */
    public function show(DisciplineRequest $request, Discipline $discipline)
    {
        if (!$discipline->exists) {
            return response()->view('nico::admin.discipline.new', compact('discipline'));
        }

        Form::populate($discipline);
        return response()->view('nico::admin.discipline.show', compact('discipline'));
    }

    /**
     * Show the form for creating a new discipline.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(DisciplineRequest $request)
    {

        $discipline = $this->repository->newInstance([]);

        Form::populate($discipline);

        return response()->view('nico::admin.discipline.create', compact('discipline'));

    }

    /**
     * Create new discipline.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(DisciplineRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.web');
            $discipline          = $this->repository->create($attributes);

            return response()->json([
                'message'  => trans('messages.success.updated', ['Module' => trans('nico::discipline.name')]),
                'code'     => 204,
                'redirect' => trans_url('/admin/nico/discipline/'.$discipline->getRouteKey())
            ], 201);


        } catch (Exception $e) {
            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
            ], 400);
        }
    }

    /**
     * Show discipline for editing.
     *
     * @param Request $request
     * @param Model   $discipline
     *
     * @return Response
     */
    public function edit(DisciplineRequest $request, Discipline $discipline)
    {
        Form::populate($discipline);
        return  response()->view('nico::admin.discipline.edit', compact('discipline'));
    }

    /**
     * Update the discipline.
     *
     * @param Request $request
     * @param Model   $discipline
     *
     * @return Response
     */
    public function update(DisciplineRequest $request, Discipline $discipline)
    {
        try {

            $attributes = $request->all();

            $discipline->update($attributes);

            return response()->json([
                'message'  => trans('messages.success.updated', ['Module' => trans('nico::discipline.name')]),
                'code'     => 204,
                'redirect' => trans_url('/admin/nico/discipline/'.$discipline->getRouteKey())
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/nico/discipline/'.$discipline->getRouteKey()),
            ], 400);

        }
    }

    /**
     * Remove the discipline.
     *
     * @param Model   $discipline
     *
     * @return Response
     */
    public function destroy(DisciplineRequest $request, Discipline $discipline)
    {

        try {

            $t = $discipline->delete();

            return response()->json([
                'message'  => trans('messages.success.deleted', ['Module' => trans('nico::discipline.name')]),
                'code'     => 202,
                'redirect' => trans_url('/admin/nico/discipline/0'),
            ], 202);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/nico/discipline/'.$discipline->getRouteKey()),
            ], 400);
        }
    }

}
